==> react-native-fbsdk-0.1.0.tgz: package/js/FBCreateAppGroupDialog.js <==
/**
 * Copyright (c) 2014-present, Facebook, Inc. All rights reserved.
 *
 * You are hereby granted a non-exclusive, worldwide, royalty-free license to use,
 * copy, modify, and distribute this software in source code or binary form for use
 * in connection with the web services and APIs provided by Facebook.
 *
 * As with any software that integrates with the Facebook platform, your use of
 * this software is subject to the Facebook Developer Principles and Policies
 * [http://developers.facebook.com/policy/]. This copyright notice shall be
 * included in all copies or substantial portions of the software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS
 * FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR
 * COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
 * IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
 * CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 *
 * @flow
 */
'use strict';

const CreateAppGroupDialog = require('react-native').NativeModules.FBCreateAppGroupDialog;
import type { AppGroupCreationContent } from './models/FBAppGroupCreationContent';

module.exports = {
  /**
   * Check if the dialog can be shown.
   */
  canShow(): Promise {
    return CreateAppGroupDialog.canShow();
  },

  /**
   * Shows the dialog using the specified content.
   */
  show(appGroupCreationContent: AppGroupCreationContent): Promise {
    return CreateAppGroupDialog.show(appGroupCreationContent);
  },
};

==> react-native-fbsdk-0.3.0.tgz: package/js/FBCreateAppGroupDialog.js <==
/**
 * Copyright (c) 2014-present, Facebook, Inc. All rights reserved.
 *
 * You are hereby granted a non-exclusive, worldwide, royalty-free license to use,
 * copy, modify, and distribute this software in source code or binary form for use
 * in connection with the web services and APIs provided by Facebook.
 *
 * As with any software that integrates with the Facebook platform, your use of
 * this software is subject to the Facebook Developer Principles and Policies
 * [http://developers.facebook.com/policy/]. This copyright notice shall be
 * included in all copies or substantial portions of the software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS
 * FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR
 * COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
 * IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
 * CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 *
 * @flow
 */
'use strict';

const CreateAppGroupDialog = require('react-native').NativeModules.FBCreateAppGroupDialog;
import type { AppGroupCreationContent } from './models/FBAppGroupCreationContent';

module.exports = {
  /**
   * Check if the dialog can be shown.
   */
  canShow(): Promise<any> {
    return CreateAppGroupDialog.canShow();
  },

  /**
   * Shows the dialog using the specified content.
   */
  show(appGroupCreationContent: AppGroupCreationContent): Promise<any> {
    return CreateAppGroupDialog.show(appGroupCreationContent);
  },
};
